@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 gnome-mpv
+ * Copyright (c) 2015-2020 gnome-mpv
  *
  * This file is part of Celluloid.
  *
@@ -24,6 +24,18 @@
 #include "celluloid-file-chooser.h"
 #include "celluloid-common.h"
 
+static gboolean
+boolean_to_state(	GBinding *binding,
+		const GValue *from_value,
+		GValue *to_value,
+		gpointer user_data );
+
+static gboolean
+state_to_boolean(	GBinding *binding,
+		const GValue *from_value,
+		GValue *to_value,
+		gpointer user_data );
+
 static gboolean
 track_id_to_state(	GBinding *binding,
 			const GValue *from_value,
@@ -88,7 +100,7 @@ static void
 stop_search_playlist_handler(GSimpleAction *action, GVariant *param, gpointer data);
 
 static void
-shuffle_playlist_handler(GSimpleAction *action, GVariant *param, gpointer data);
+toggle_shuffle_playlist_handler(GSimpleAction *action, GVariant *param, gpointer data);
 
 static void
 copy_selected_playlist_item_handler(	GSimpleAction *action,
@@ -141,6 +153,34 @@ show_about_dialog_handler(	GSimpleAction *action,
 				GVariant *param,
 				gpointer data );
 
+static gboolean
+boolean_to_state(	GBinding *binding,
+		const GValue *from_value,
+		GValue *to_value,
+		gpointer user_data )
+{
+	gboolean from = g_value_get_boolean(from_value);
+	GVariant *to = g_variant_new("b", from);
+
+	g_value_set_variant(to_value, to);
+
+	return TRUE;
+}
+
+static gboolean
+state_to_boolean(	GBinding *binding,
+		const GValue *from_value,
+		GValue *to_value,
+		gpointer user_data )
+{
+	GVariant *from = g_value_get_variant(from_value);
+	gboolean to = g_variant_get_boolean(from);
+
+	g_value_set_boolean(to_value, to);
+
+	return TRUE;
+}
+
 static gboolean
 track_id_to_state(	GBinding *binding,
 			const GValue *from_value,
@@ -238,6 +278,16 @@ bind_properties(CelluloidController *controller)
 					NULL,
 					NULL );
 
+	action =	g_action_map_lookup_action
+			(G_ACTION_MAP(window), "toggle-shuffle-playlist");
+	g_object_bind_property_full(	controller->model, "shuffle",
+					action, "state",
+					G_BINDING_BIDIRECTIONAL,
+					boolean_to_state,
+					state_to_boolean,
+					NULL,
+					NULL );
+
 	action =	g_action_map_lookup_action
 			(G_ACTION_MAP(window), "toggle-loop-file");
 	g_object_bind_property_full(	controller->model, "loop-file",
@@ -274,10 +324,13 @@ open_handler(GSimpleAction *action, GVariant *param, gpointer data)
 static void
 show_open_dialog_handler(GSimpleAction *action, GVariant *param, gpointer data)
 {
-	gboolean append = g_variant_get_boolean(param);
+	gboolean folder = FALSE;
+	gboolean append = FALSE;
+
+	g_variant_get(param, "(bb)", &folder, &append);
 
 	celluloid_view_show_open_dialog
-		(celluloid_controller_get_view(data), append);
+		(celluloid_controller_get_view(data), folder, append);
 }
 
 static void
@@ -347,9 +400,9 @@ stop_search_playlist_handler(GSimpleAction *action, GVariant *param, gpointer da
 }
 
 static void
-shuffle_playlist_handler(GSimpleAction *action, GVariant *param, gpointer data)
+toggle_shuffle_playlist_handler(GSimpleAction *action, GVariant *value, gpointer data)
 {
-	celluloid_model_shuffle_playlist(celluloid_controller_get_model(data));
+	g_simple_action_set_state(action, value);
 }
 
 static void
@@ -434,6 +487,10 @@ load_track_handler(GSimpleAction *action, GVariant *param, gpointer data)
 	{
 		celluloid_view_show_open_audio_track_dialog(view);
 	}
+	else if(g_strcmp0(cmd_name, "video-add") == 0)
+	{
+		celluloid_view_show_open_video_track_dialog(view);
+	}
 	else if(g_strcmp0(cmd_name, "sub-add") == 0)
 	{
 		celluloid_view_show_open_subtitle_track_dialog(view);
@@ -492,7 +549,7 @@ celluloid_controller_action_register_actions(CelluloidController *controller)
 			.parameter_type = "(sb)"},
 			{.name = "show-open-dialog",
 			.activate = show_open_dialog_handler,
-			.parameter_type = "b"},
+			.parameter_type = "(bb)"},
 			{.name = "quit",
 			.activate = quit_handler},
 			{.name = "show-about-dialog",
@@ -520,8 +577,9 @@ celluloid_controller_action_register_actions(CelluloidController *controller)
 			.activate = search_playlist_handler},
 			{.name = "stop-search-playlist",
 			.activate = stop_search_playlist_handler},
-			{.name = "shuffle-playlist",
-			.activate = shuffle_playlist_handler},
+			{.name = "toggle-shuffle-playlist",
+			.state = "false",
+			.change_state = toggle_shuffle_playlist_handler},
 			{.name = "copy-selected-playlist-item",
 			.activate = copy_selected_playlist_item_handler},
 			{.name = "remove-selected-playlist-item",
