@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 gnome-mpv
+ * Copyright (c) 2017-2020 gnome-mpv
  *
  * This file is part of Celluloid.
  *
@@ -21,6 +21,7 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
+#include "celluloid-option-parser.h"
 #include "celluloid-player.h"
 #include "celluloid-player-private.h"
 #include "celluloid-player-options.h"
@@ -72,7 +73,7 @@ static void
 initialize(CelluloidMpv *mpv);
 
 static gint
-apply_options_array_string(CelluloidMpv *mpv, gchar *args);
+apply_options_array_string(CelluloidMpv *mpv, const gchar *args);
 
 static void
 apply_extra_options(CelluloidPlayer *player);
@@ -428,6 +429,8 @@ observe_properties(CelluloidMpv *mpv)
 	celluloid_mpv_observe_property(mpv, 0, "track-list", MPV_FORMAT_NODE);
 	celluloid_mpv_observe_property(mpv, 0, "vo-configured", MPV_FORMAT_FLAG);
 	celluloid_mpv_observe_property(mpv, 0, "volume", MPV_FORMAT_DOUBLE);
+	celluloid_mpv_observe_property(mpv, 0, "volume-max", MPV_FORMAT_DOUBLE);
+	celluloid_mpv_observe_property(mpv, 0, "window-maximized", MPV_FORMAT_FLAG);
 	celluloid_mpv_observe_property(mpv, 0, "window-scale", MPV_FORMAT_DOUBLE);
 }
 
@@ -503,37 +506,32 @@ initialize(CelluloidMpv *mpv)
 }
 
 static gint
-apply_options_array_string(CelluloidMpv *mpv, gchar *args)
+apply_options_array_string(CelluloidMpv *mpv, const gchar *args)
 {
 	gint fail_count = 0;
-	gchar **tokens = g_regex_split_simple(	"(^|\\s+)--",
-						args,
-						G_REGEX_NO_AUTO_CAPTURE,
-						0 );
 
-	/* Skip the first token if it's non-NULL, since it is just going to be
-	 * empty string for any valid args.
-	 */
-	for(gint i = tokens[0]?1:0; tokens[i]; i++)
+	while(args && *args)
 	{
-		gchar **parts = g_strsplit(g_strchomp(tokens[i]), "=", 2);
-		const gchar *option = parts[0];
-		const gchar *value = (option?parts[1]:NULL)?:"";
+		gchar *key = NULL;
+		gchar *value = NULL;
 
-		g_debug("Applying option: --%s", tokens[i]);
+		args = parse_option(args, &key, &value);
 
-		if(celluloid_mpv_set_option_string(mpv, option, value) < 0)
+		g_debug("Applying option: --%s=%s", key, value);
+
+		if(celluloid_mpv_set_option_string(mpv, key, value) < 0)
 		{
 			fail_count++;
 
-			g_warning("Failed to apply option: --%s\n", tokens[i]);
+			g_warning(	"Failed to apply option: --%s=%s\n",
+					key,
+					value );
 		}
 
-		g_strfreev(parts);
+		g_free(key);
+		g_free(value);
 	}
 
-	g_strfreev(tokens);
-
 	return fail_count*(-1);
 }
 
