@@ -379,6 +379,8 @@ constructed(GObject *object)
 		(GTK_TREE_VIEW(self->tree_view), self->title_column);
 
 	gtk_overlay_add_overlay(GTK_OVERLAY(self->overlay), self->placeholder);
+	gtk_overlay_set_overlay_pass_through
+		(GTK_OVERLAY(self->overlay), self->placeholder, TRUE);
 
 	gtk_container_add(GTK_CONTAINER(self->overlay), self->tree_view);
 	gtk_container_add(GTK_CONTAINER(self->scrolled_window), self->overlay);
@@ -784,9 +786,10 @@ mouse_press_handler(GtkWidget *widget, GdkEventButton *event, gpointer data)
 				CELLULOID_MENU_ITEM(_("_Copy Location"), "win.copy-selected-playlist-item"),
 				CELLULOID_MENU_ITEM(_("_Remove"), "win.remove-selected-playlist-item"),
 				CELLULOID_MENU_SEPARATOR,
-				CELLULOID_MENU_ITEM(_("_Add…"), "win.show-open-dialog(true)"),
+				CELLULOID_MENU_ITEM(_("_Add…"), "win.show-open-dialog((false, true))"),
+				CELLULOID_MENU_ITEM(_("Add _Folder…"), "win.show-open-dialog((true, true))"),
 				CELLULOID_MENU_ITEM(_("Add _Location…"), "win.show-open-location-dialog(true)"),
-				CELLULOID_MENU_ITEM(_("_Shuffle"), "win.shuffle-playlist"),
+				CELLULOID_MENU_ITEM(_("_Shuffle"), "win.toggle-shuffle-playlist"),
 				CELLULOID_MENU_ITEM(_("Loop _File"), "win.toggle-loop-file"),
 				CELLULOID_MENU_ITEM(_("Loop _Playlist"), "win.toggle-loop-playlist"),
 				CELLULOID_MENU_END };
