@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 gnome-mpv
+ * Copyright (c) 2017-2020 gnome-mpv
  *
  * This file is part of Celluloid.
  *
@@ -36,26 +36,33 @@ enum
 	PROP_PLAYLIST_COUNT,
 	PROP_PAUSE,
 	PROP_VOLUME,
+	PROP_VOLUME_MAX,
 	PROP_DURATION,
 	PROP_PLAYLIST_POS,
 	PROP_TRACK_LIST,
 	PROP_DISC_LIST,
 	PROP_SKIP_ENABLED,
 	PROP_LOOP,
+	PROP_SHUFFLE,
 	PROP_BORDER,
 	PROP_FULLSCREEN,
+	PROP_MAXIMIZED,
 	PROP_DISPLAY_FPS,
+	PROP_SEARCHING,
 	N_PROPERTIES
 };
 
 struct _CelluloidView
 {
 	CelluloidMainWindow parent;
+	gboolean disposed;
+	gboolean has_dialog;
 
 	/* Properties */
 	gint playlist_count;
 	gboolean pause;
 	gdouble volume;
+	gdouble volume_max;
 	gdouble duration;
 	gint playlist_pos;
 	GPtrArray *track_list;
@@ -63,9 +70,12 @@ struct _CelluloidView
 	gboolean skip_enabled;
 	gboolean control_box_enabled;
 	gboolean loop;
+	gboolean shuffle;
 	gboolean border;
 	gboolean fullscreen;
+	gboolean maximized;
 	gdouble display_fps;
+	gboolean searching;
 };
 
 struct _CelluloidViewClass
@@ -78,6 +88,9 @@ G_DEFINE_TYPE(CelluloidView, celluloid_view, CELLULOID_TYPE_MAIN_WINDOW)
 static void
 constructed(GObject *object);
 
+static void
+dispose(GObject *object);
+
 static void
 set_property(	GObject *object,
 		guint property_id,
@@ -100,7 +113,7 @@ static void
 save_playlist(CelluloidView *view, GFile *file, GError **error);
 
 static void
-show_message_dialog(	CelluloidMainWindow *wnd,
+show_message_dialog(	CelluloidView *view,
 			GtkMessageType type,
 			const gchar *title,
 			const gchar *prefix,
@@ -109,7 +122,15 @@ show_message_dialog(	CelluloidMainWindow *wnd,
 static void
 update_display_fps(CelluloidView *view);
 
+static void
+show_open_track_dialog(CelluloidView  *view, TrackType type);
+
 /* Dialog responses */
+static void
+message_dialog_response_handler(	GtkDialog *dialog,
+					gint response_id,
+					gpointer data);
+
 static void
 open_dialog_response_handler(GtkDialog *dialog, gint response_id, gpointer data);
 
@@ -119,13 +140,9 @@ open_location_dialog_response_handler(	GtkDialog *dialog,
 					gpointer data );
 
 static void
-open_audio_track_dialog_response_handler(	GtkDialog *dialog,
-						gint response_id,
-						gpointer data );
-static void
-open_subtitle_track_dialog_response_handler(	GtkDialog *dialog,
-						gint response_id,
-						gpointer data );
+open_track_dialog_response_handler(	GtkDialog *dialog,
+					gint response_id,
+					gpointer data );
 
 static void
 preferences_dialog_response_handler(	GtkDialog *dialog,
@@ -204,13 +221,12 @@ constructed(GObject *object)
 	CelluloidControlBox *control_box =
 		celluloid_main_window_get_control_box(wnd);
 
-	celluloid_main_window_load_state(wnd);
-	load_css(view);
-	load_settings(view);
-
 	g_object_bind_property(	view, "duration",
 				control_box, "duration",
 				G_BINDING_DEFAULT );
+	g_object_bind_property(	wnd, "is-maximized",
+				view, "maximized",
+				G_BINDING_DEFAULT );
 	g_object_bind_property(	view, "pause",
 				control_box, "pause",
 				G_BINDING_DEFAULT );
@@ -220,12 +236,25 @@ constructed(GObject *object)
 	g_object_bind_property(	view, "loop",
 				control_box, "loop",
 				G_BINDING_BIDIRECTIONAL );
+	g_object_bind_property(	view, "shuffle",
+				control_box, "shuffle",
+				G_BINDING_BIDIRECTIONAL );
 	g_object_bind_property(	view, "volume",
 				control_box, "volume",
 				G_BINDING_BIDIRECTIONAL );
+	g_object_bind_property(	view, "volume-max",
+				control_box, "volume-max",
+				G_BINDING_DEFAULT );
 	g_object_bind_property(	playlist, "playlist-count",
 				view, "playlist-count",
 				G_BINDING_DEFAULT );
+	g_object_bind_property(	playlist, "searching",
+				view, "searching",
+				G_BINDING_BIDIRECTIONAL );
+
+	celluloid_main_window_load_state(wnd);
+	load_css(view);
+	load_settings(view);
 
 	g_signal_connect(	video_area,
 				"size-allocate",
@@ -273,6 +302,20 @@ constructed(GObject *object)
 				view );
 }
 
+static void
+dispose(GObject *object)
+{
+	CelluloidView *view = CELLULOID_VIEW(object);
+
+	if(!view->disposed)
+	{
+		celluloid_main_window_save_state(CELLULOID_MAIN_WINDOW(object));
+		view->disposed = TRUE;
+	}
+
+	G_OBJECT_CLASS(celluloid_view_parent_class)->dispose(object);
+}
+
 static void
 set_property(	GObject *object,
 		guint property_id,
@@ -310,6 +353,10 @@ set_property(	GObject *object,
 		self->volume = g_value_get_double(value);
 		break;
 
+		case PROP_VOLUME_MAX:
+		self->volume_max = g_value_get_double(value);
+		break;
+
 		case PROP_DURATION:
 		self->duration = g_value_get_double(value);
 		break;
@@ -342,6 +389,10 @@ set_property(	GObject *object,
 		self->loop = g_value_get_boolean(value);
 		break;
 
+		case PROP_SHUFFLE:
+		self->shuffle = g_value_get_boolean(value);
+		break;
+
 		case PROP_BORDER:
 		self->border = g_value_get_boolean(value);
 		gtk_window_set_decorated(GTK_WINDOW(wnd), self->border);
@@ -352,10 +403,37 @@ set_property(	GObject *object,
 		celluloid_main_window_set_fullscreen(wnd, self->fullscreen);
 		break;
 
+		case PROP_MAXIMIZED:
+		self->maximized = g_value_get_boolean(value);
+
+		if(self->maximized)
+		{
+			gtk_window_maximize(GTK_WINDOW(wnd));
+		}
+		else
+		{
+			gtk_window_unmaximize(GTK_WINDOW(wnd));
+		}
+		break;
+
 		case PROP_DISPLAY_FPS:
 		self->display_fps = g_value_get_double(value);
 		break;
 
+		case PROP_SEARCHING:
+		// We do not display playlist in fullscreen mode so refuse to
+		// enter search mode here if we're in fullscreen mode.
+		self->searching =	!self->fullscreen &&
+					g_value_get_boolean(value);
+
+		// Show playlist if we're about to enter search mode and it
+		// isn't already visible.
+		if(self->searching && !celluloid_view_get_playlist_visible(self))
+		{
+			celluloid_view_set_playlist_visible(self, TRUE);
+		}
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -384,6 +462,10 @@ get_property(	GObject *object,
 		g_value_set_double(value, self->volume);
 		break;
 
+		case PROP_VOLUME_MAX:
+		g_value_set_double(value, self->volume_max);
+		break;
+
 		case PROP_DURATION:
 		g_value_set_double(value, self->duration);
 		break;
@@ -408,6 +490,10 @@ get_property(	GObject *object,
 		g_value_set_boolean(value, self->loop);
 		break;
 
+		case PROP_SHUFFLE:
+		g_value_set_boolean(value, self->shuffle);
+		break;
+
 		case PROP_BORDER:
 		g_value_set_boolean(value, self->border);
 		break;
@@ -416,10 +502,18 @@ get_property(	GObject *object,
 		g_value_set_boolean(value, self->fullscreen);
 		break;
 
+		case PROP_MAXIMIZED:
+		g_value_set_boolean(value, self->maximized);
+		break;
+
 		case PROP_DISPLAY_FPS:
 		g_value_set_double(value, self->display_fps);
 		break;
 
+		case PROP_SEARCHING:
+		g_value_set_boolean(value, self->searching);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -433,7 +527,8 @@ load_css(CelluloidView *view)
 	GtkCssProvider *style_provider;
 	gboolean css_loaded;
 
-	style = ".celluloid-video-area{background-color: black}";
+	style =	"celluloid-video-area{background-color: black}"
+		"celluloid-preferences-dialog .dialog-action-box{margin-right: 12px}";
 	style_provider = gtk_css_provider_new();
 	css_loaded =	gtk_css_provider_load_from_data
 			(style_provider, style, -1, NULL);
@@ -526,23 +621,36 @@ save_playlist(CelluloidView *view, GFile *file, GError **error)
 }
 
 void
-show_message_dialog(	CelluloidMainWindow *wnd,
+show_message_dialog(	CelluloidView *view,
 			GtkMessageType type,
 			const gchar *title,
 			const gchar *prefix,
 			const gchar *msg )
 {
-	GtkWidget *dialog;
-	GtkWidget *msg_area;
-	GList *children;
+	GtkWidget *dialog = NULL;
+	GtkWidget *msg_area = NULL;
+	GList *children = NULL;
 
-	if(prefix)
+	if(view->has_dialog)
+	{
+		g_info("Error dialog suppressed because one is already being shown");
+
+		if(prefix)
+		{
+			g_info("Content: *%s* [%s] %s", title, prefix, msg);
+		}
+		else
+		{
+			g_info("Content: *%s* %s", title, msg);
+		}
+	}
+	else if(prefix)
 	{
 		gchar *prefix_escaped = g_markup_printf_escaped("%s", prefix);
 		gchar *msg_escaped = g_markup_printf_escaped("%s", msg);
 
 		dialog =	gtk_message_dialog_new_with_markup
-				(	GTK_WINDOW(wnd),
+				(	GTK_WINDOW(view),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					type,
 					GTK_BUTTONS_OK,
@@ -556,7 +664,7 @@ show_message_dialog(	CelluloidMainWindow *wnd,
 	else
 	{
 		dialog =	gtk_message_dialog_new
-				(	GTK_WINDOW(wnd),
+				(	GTK_WINDOW(view),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					type,
 					GTK_BUTTONS_OK,
@@ -564,29 +672,35 @@ show_message_dialog(	CelluloidMainWindow *wnd,
 					msg );
 	}
 
-	msg_area =	gtk_message_dialog_get_message_area
-			(GTK_MESSAGE_DIALOG(dialog));
-	children = gtk_container_get_children(GTK_CONTAINER(msg_area));
-
-	for(GList *iter = children; iter; iter = g_list_next(iter))
+	if(dialog)
 	{
-		if(GTK_IS_LABEL(iter->data))
+		view->has_dialog = TRUE;
+		msg_area =	gtk_message_dialog_get_message_area
+				(GTK_MESSAGE_DIALOG(dialog));
+		children = gtk_container_get_children(GTK_CONTAINER(msg_area));
+
+		for(GList *iter = children; iter; iter = g_list_next(iter))
 		{
-			gtk_label_set_line_wrap_mode
-				(GTK_LABEL(iter->data), PANGO_WRAP_WORD_CHAR);
+			if(GTK_IS_LABEL(iter->data))
+			{
+				gtk_label_set_line_wrap_mode
+					(	GTK_LABEL(iter->data),
+						PANGO_WRAP_WORD_CHAR );
+			}
 		}
-	}
 
-	g_list_free(children);
+		g_list_free(children);
 
-	g_signal_connect(	dialog,
+		g_signal_connect
+			(	dialog,
 				"response",
-				G_CALLBACK(gtk_widget_destroy),
-				NULL );
+				G_CALLBACK(message_dialog_response_handler),
+				view );
 
-	gtk_window_set_title(GTK_WINDOW(dialog), title);
-	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-	gtk_widget_show_all(dialog);
+		gtk_window_set_title(GTK_WINDOW(dialog), title);
+		gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
+		gtk_widget_show_all(dialog);
+	}
 }
 
 static void
@@ -603,6 +717,64 @@ update_display_fps(CelluloidView *view)
 	g_object_notify(G_OBJECT(view), "display-fps");
 }
 
+static void
+show_open_track_dialog(CelluloidView  *view, TrackType type)
+{
+	const gchar *title = NULL;
+
+	switch(type)
+	{
+		case TRACK_TYPE_AUDIO:
+		title = _("Load Audio Track…");
+		break;
+
+		case TRACK_TYPE_VIDEO:
+		title = _("Load Video Track…");
+		break;
+
+		case TRACK_TYPE_SUBTITLE:
+		title = _("Load Subtitle Track…");
+		break;
+
+		default:
+		g_assert_not_reached();
+		break;
+	}
+
+	CelluloidFileChooser *chooser =	celluloid_file_chooser_new
+					(	title,
+						GTK_WINDOW(view),
+						GTK_FILE_CHOOSER_ACTION_OPEN );
+
+	g_object_set_data(	G_OBJECT(chooser),
+				"track-type",
+				(gpointer)type );
+
+	g_signal_connect(	chooser,
+				"response",
+				G_CALLBACK(open_track_dialog_response_handler),
+				view );
+
+	celluloid_file_chooser_set_default_filters
+		(	chooser,
+			type == TRACK_TYPE_AUDIO,
+			type == TRACK_TYPE_VIDEO,
+			FALSE,
+			type == TRACK_TYPE_SUBTITLE );
+
+	celluloid_file_chooser_show(chooser);
+}
+
+static void
+message_dialog_response_handler(	GtkDialog *dialog,
+					gint response_id,
+					gpointer data)
+{
+	CELLULOID_VIEW(data)->has_dialog = FALSE;
+
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
 static void
 open_dialog_response_handler(GtkDialog *dialog, gint response_id, gpointer data)
 {
@@ -661,39 +833,42 @@ open_location_dialog_response_handler(	GtkDialog *dialog,
 }
 
 static void
-open_audio_track_dialog_response_handler(	GtkDialog *dialog,
-						gint response_id,
-						gpointer data )
+open_track_dialog_response_handler(	GtkDialog *dialog,
+					gint response_id,
+					gpointer data )
 {
 	if(response_id == GTK_RESPONSE_ACCEPT)
 	{
 		GtkFileChooser *chooser = GTK_FILE_CHOOSER(dialog);
 		GSList *uri_list = gtk_file_chooser_get_filenames(chooser);
+		const gchar *name = NULL;
 
-		for(GSList *iter = uri_list; iter; iter = g_slist_next(iter))
+		TrackType type =
+			(TrackType)
+			g_object_get_data(G_OBJECT(dialog), "track-type");
+
+		switch(type)
 		{
-			g_signal_emit_by_name(data, "audio-track-load", *iter);
+			case TRACK_TYPE_AUDIO:
+			name = "audio-track-load";
+			break;
+
+			case TRACK_TYPE_VIDEO:
+			name = "video-track-load";
+			break;
+
+			case TRACK_TYPE_SUBTITLE:
+			name = "subtitle-track-load";
+			break;
+
+			default:
+			g_assert_not_reached();
+			break;
 		}
 
-		g_slist_free_full(uri_list, g_free);
-	}
-
-	celluloid_file_chooser_destroy(CELLULOID_FILE_CHOOSER(dialog));
-}
-
-static void
-open_subtitle_track_dialog_response_handler(	GtkDialog *dialog,
-						gint response_id,
-						gpointer data )
-{
-	if(response_id == GTK_RESPONSE_ACCEPT)
-	{
-		GtkFileChooser *chooser = GTK_FILE_CHOOSER(dialog);
-		GSList *uri_list = gtk_file_chooser_get_filenames(chooser);
-
 		for(GSList *iter = uri_list; iter; iter = g_slist_next(iter))
 		{
-			g_signal_emit_by_name(data, "subtitle-track-load", *iter);
+			g_signal_emit_by_name(data, name, *iter);
 		}
 
 		g_slist_free_full(uri_list, g_free);
@@ -719,7 +894,7 @@ preferences_dialog_response_handler(	GtkDialog *dialog,
 
 		if(celluloid_main_window_get_csd_enabled(wnd) != csd_enable)
 		{
-			show_message_dialog(	wnd,
+			show_message_dialog(	CELLULOID_VIEW(data),
 						GTK_MESSAGE_INFO,
 						g_get_application_name(),
 						NULL,
@@ -916,6 +1091,7 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 	GParamSpec *pspec = NULL;
 
 	object_class->constructed = constructed;
+	object_class->dispose = dispose;
 	object_class->set_property = set_property;
 	object_class->get_property = get_property;
 
@@ -947,6 +1123,16 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 			G_PARAM_READWRITE );
 	g_object_class_install_property(object_class, PROP_VOLUME, pspec);
 
+	pspec = g_param_spec_double
+		(	"volume-max",
+			"Volume Max",
+			"The maximum amplification level",
+			0.0,
+			G_MAXDOUBLE,
+			100.0,
+			G_PARAM_READWRITE );
+	g_object_class_install_property(object_class, PROP_VOLUME_MAX, pspec);
+
 	pspec = g_param_spec_double
 		(	"duration",
 			"Duration",
@@ -961,9 +1147,9 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 		(	"playlist-pos",
 			"Playlist position",
 			"The position of the current item in playlist",
-			0,
+			-1,
 			G_MAXINT,
-			0,
+			-1,
 			G_PARAM_READWRITE );
 	g_object_class_install_property(object_class, PROP_PLAYLIST_POS, pspec);
 
@@ -997,6 +1183,14 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 			G_PARAM_READWRITE );
 	g_object_class_install_property(object_class, PROP_LOOP, pspec);
 
+	pspec = g_param_spec_boolean
+		(	"shuffle",
+			"Shuffle",
+			"Whether or not the the shuffle button is active",
+			FALSE,
+			G_PARAM_READWRITE );
+	g_object_class_install_property(object_class, PROP_SHUFFLE, pspec);
+
 	pspec = g_param_spec_boolean
 		(	"border",
 			"Border",
@@ -1013,6 +1207,14 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 			G_PARAM_READWRITE );
 	g_object_class_install_property(object_class, PROP_FULLSCREEN, pspec);
 
+	pspec = g_param_spec_boolean
+		(	"maximized",
+			"Maximized",
+			"Whether or not the main window is maximized",
+			FALSE,
+			G_PARAM_READWRITE );
+	g_object_class_install_property(object_class, PROP_MAXIMIZED, pspec);
+
 	pspec = g_param_spec_double
 		(	"display-fps",
 			"Display FPS",
@@ -1023,6 +1225,14 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 			G_PARAM_READABLE );
 	g_object_class_install_property(object_class, PROP_DISPLAY_FPS, pspec);
 
+	pspec = g_param_spec_boolean
+		(	"searching",
+			"Searching",
+			"Whether or not the user is searching the playlist",
+			FALSE,
+			G_PARAM_READWRITE );
+	g_object_class_install_property(object_class, PROP_SEARCHING, pspec);
+
 	g_signal_new(	"video-area-resize",
 			G_TYPE_FROM_CLASS(klass),
 			G_SIGNAL_RUN_FIRST|G_SIGNAL_DETAILED,
@@ -1083,6 +1293,16 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 			G_TYPE_NONE,
 			1,
 			G_TYPE_STRING );
+	g_signal_new(	"video-track-load",
+			G_TYPE_FROM_CLASS(klass),
+			G_SIGNAL_RUN_FIRST,
+			0,
+			NULL,
+			NULL,
+			g_cclosure_marshal_VOID__STRING,
+			G_TYPE_NONE,
+			1,
+			G_TYPE_STRING );
 	g_signal_new(	"subtitle-track-load",
 			G_TYPE_FROM_CLASS(klass),
 			G_SIGNAL_RUN_FIRST,
@@ -1150,17 +1370,23 @@ celluloid_view_class_init(CelluloidViewClass *klass)
 static void
 celluloid_view_init(CelluloidView *view)
 {
+	view->disposed = FALSE;
+	view->has_dialog = FALSE;
 	view->playlist_count = 0;
 	view->pause = FALSE;
 	view->volume = 0.0;
+	view->volume_max = 100.0;
 	view->duration = 0.0;
 	view->playlist_pos = 0;
 	view->disc_list = NULL;
 	view->skip_enabled = FALSE;
 	view->loop = FALSE;
+	view->shuffle = FALSE;
 	view->border = FALSE;
 	view->fullscreen = FALSE;
+	view->maximized = FALSE;
 	view->display_fps = 0;
+	view->searching = FALSE;
 
 	g_signal_connect(view, "realize", G_CALLBACK(realize_handler), NULL);
 	g_signal_connect_after(view, "draw", G_CALLBACK(draw_handler), NULL);
@@ -1203,17 +1429,28 @@ celluloid_view_get_main_window(CelluloidView *view)
 }
 
 void
-celluloid_view_show_open_dialog(CelluloidView *view, gboolean append)
+celluloid_view_show_open_dialog(	CelluloidView *view,
+					gboolean folder,
+					gboolean append )
 {
 	CelluloidFileChooser *chooser;
 	GPtrArray *args;
+	const gchar *title;
+	GtkFileChooserAction action;
 	gboolean *append_buf;
 
-	chooser = celluloid_file_chooser_new(	append?
-						_("Add File to Playlist"):
-						_("Open File"),
-						GTK_WINDOW(view),
-						GTK_FILE_CHOOSER_ACTION_OPEN );
+	if(folder)
+	{
+		title = append ? _("Add Folder to Playlist") : _("Open Folder");
+		action = GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
+	}
+	else
+	{
+		title = append ? _("Add File to Playlist") : _("Open File");
+		action = GTK_FILE_CHOOSER_ACTION_OPEN;
+	}
+
+	chooser = celluloid_file_chooser_new(title, GTK_WINDOW(view), action);
 	args = g_ptr_array_new();
 	append_buf = g_malloc(sizeof(gboolean));
 	*append_buf = append;
@@ -1226,7 +1463,12 @@ celluloid_view_show_open_dialog(CelluloidView *view, gboolean append)
 				G_CALLBACK(open_dialog_response_handler),
 				args );
 
-	celluloid_file_chooser_set_default_filters(chooser, TRUE, TRUE, TRUE, TRUE);
+	if(!folder)
+	{
+		celluloid_file_chooser_set_default_filters
+			(chooser, TRUE, TRUE, TRUE, TRUE);
+	}
+
 	celluloid_file_chooser_show(chooser);
 }
 
@@ -1262,41 +1504,19 @@ celluloid_view_show_open_location_dialog(CelluloidView *view, gboolean append)
 void
 celluloid_view_show_open_audio_track_dialog(CelluloidView *view)
 {
-	CelluloidFileChooser *chooser =	celluloid_file_chooser_new
-					(	_("Load Audio Track…"),
-						GTK_WINDOW(view),
-						GTK_FILE_CHOOSER_ACTION_OPEN );
+	show_open_track_dialog(view, TRACK_TYPE_AUDIO);
+}
 
-	g_signal_connect
-		(	chooser,
-			"response",
-			G_CALLBACK(open_audio_track_dialog_response_handler),
-			view );
-
-	celluloid_file_chooser_set_default_filters
-		(chooser, TRUE, FALSE, FALSE, FALSE);
-
-	celluloid_file_chooser_show(chooser);
+void
+celluloid_view_show_open_video_track_dialog(CelluloidView *view)
+{
+	show_open_track_dialog(view, TRACK_TYPE_VIDEO);
 }
 
 void
 celluloid_view_show_open_subtitle_track_dialog(CelluloidView *view)
 {
-	CelluloidFileChooser *chooser =	celluloid_file_chooser_new
-					(	_("Load Subtitle Track…"),
-						GTK_WINDOW(view),
-						GTK_FILE_CHOOSER_ACTION_OPEN );
-
-	g_signal_connect
-		(	chooser,
-			"response",
-			G_CALLBACK(open_subtitle_track_dialog_response_handler),
-			view );
-
-	celluloid_file_chooser_set_default_filters
-		(chooser, FALSE, FALSE, FALSE, TRUE);
-
-	celluloid_file_chooser_show(chooser);
+	show_open_track_dialog(view, TRACK_TYPE_SUBTITLE);
 }
 
 void
@@ -1333,7 +1553,7 @@ celluloid_view_show_save_playlist_dialog(CelluloidView *view)
 
 	if(error)
 	{
-		show_message_dialog(	CELLULOID_MAIN_WINDOW(view),
+		show_message_dialog(	view,
 					GTK_MESSAGE_ERROR,
 					_("Error"),
 					NULL,
@@ -1381,7 +1601,7 @@ celluloid_view_show_about_dialog(CelluloidView *view)
 				"license-type",
 				GTK_LICENSE_GPL_3_0,
 				"copyright",
-				"\u00A9 2014-2019 The Celluloid authors",
+				"\u00A9 2014-2020 The Celluloid authors",
 				"authors",
 				authors,
 				"translator-credits",
@@ -1396,8 +1616,7 @@ celluloid_view_show_message_dialog(	CelluloidView *view,
 					const gchar *prefix,
 					const gchar *msg )
 {
-	show_message_dialog
-		(CELLULOID_MAIN_WINDOW(view), type, title, prefix, msg);
+	show_message_dialog(view, type, title, prefix, msg);
 }
 
 void
@@ -1522,11 +1741,8 @@ celluloid_view_move(	CelluloidView *view,
 void
 celluloid_view_resize_video_area(CelluloidView *view, gint width, gint height)
 {
-	if(!view->fullscreen)
-	{
-		celluloid_main_window_resize_video_area
-			(CELLULOID_MAIN_WINDOW(view), width, height);
-	}
+	celluloid_main_window_resize_video_area
+		(CELLULOID_MAIN_WINDOW(view), width, height);
 }
 
 void
